#include <chronoptics/tof.hpp>
#include <iostream>
#include <thread>

namespace tof = chronoptics::tof;

void capture_complex_averaged_data(const char* file_name, int average_n_frames,
                                   const char* serial) {
  tof::ProcessingConfig config{};

  // Disable calibration, such that it can be applied normally for reprocessing
  config.set_calibration_enabled(false);

  tof::KeaCamera cam(config, serial);
  cam.set_on_camera_processing(false);

  tof::CsfWriter writer = tof::create_csf_writer_camera(file_name, cam);

  tof::select_streams(cam, {tof::FrameType::REAL, tof::FrameType::IMAGINARY});
  cam.start();

  std::cout << "Dropping frames for 2 seconds\n";

  // Wait for illumination to warm up
  std::this_thread::sleep_for(std::chrono::seconds{2});

  config.set_average_enabled(true);
  config.set_average_nframes(average_n_frames);

  cam.set_process_config(config);

  std::cout << "Averaging frames together\n";

  // Wait for data to be averaged, depending on the number of averages this
  // might take a long time. If it takes over 30 seconds, the cam.getFrames()
  // function will throw
  while (!cam.has_frames()) {
    std::this_thread::sleep_for(std::chrono::milliseconds{100});
  }

  auto frames = cam.get_frames();

  for (const auto& frame : frames) {
    writer.write_frame(frame);
  }

  std::cout << "Capture finished\n";
}

void process_complex_averaged_data(const char* file_name) {
  tof::ProcessingConfig config{};

  // Adjust the processing config to your liking

  tof::CsfCamera cam(config, file_name);
  tof::select_streams(cam, {tof::FrameType::Z});
  cam.start();

  auto frames = cam.get_frames();
  (void)frames;

  // Do something with the averaged frames
}

int main() {
  auto file_name = "complex.csf";
  capture_complex_averaged_data(file_name, 100, "202001a");
  process_complex_averaged_data(file_name);
}