% Example of streaming RGB data from a Kea camera if it is avaliable.
cam = tof.KeaCamera(tof.ProcessingConfig(), "202001a");

if tof.selectStreams(cam, [tof.FrameType.BGR]) == 0
    disp("RGB not supported on current camera")
    return
end

% Fixed image size.
nrows = 1920;
ncols = 1080;
nchs = 3;

img = zeros(nrows, ncols, nchs, 'uint8');
fig = figure();
subplot(111);
imhandle = imagesc(zeros(ncols, nrows, nchs, 'uint8'), [0 255]);
ax1 = gca;
title('RGB');

% When we close the window stop the camera
set(fig, 'CloseRequestFcn', 'cam.stop(); closereq')

cam.start();

while cam.isStreaming()
    frames = cam.getFrames();
    bgr_img = frames(1).data();

    % Now move around for a good looking RGB image to be display
    img(:, :, 1) = bgr_img(3, :, :);
    img(:, :, 2) = bgr_img(2, :, :);
    img(:, :, 3) = bgr_img(1, :, :);

    set(imhandle, 'CData', rot90(img, 1));
    title(['frame: ' num2str(frames(1).frameCount())]);
    drawnow;
end
